@@ -14,11 +14,11 @@ __PACKAGE__->collection_name('Groups');
 has 'groupId' => (is => 'rw', isa => 'Str', required => 1);
 __PACKAGE__->primary_key('groupId');
 
-has 'name' => (is => 'rw', isa => 'Str', required => 1,
+has 'name' => (is => 'rw', isa => 'Str',
 	       documentation => 'name of the group');
 __PACKAGE__->_alias(groupName => 'name', freeze => 1);
 
-has 'members' => (is => 'rw', isa => 'Elive::Array', required => 1,
+has 'members' => (is => 'rw', isa => 'Elive::Array',
 		  coerce => 1,
 		  documentation => "ids of users in the group");
 __PACKAGE__->_alias(groupMembers => 'members', freeze => 1);
@@ -26,6 +26,18 @@ __PACKAGE__->_alias(groupMembers => 'members', freeze => 1);
 has 'dn' => (is => 'rw', isa => 'Str',
 	       documentation => 'LDAP Domain (where applicable)');
 
+coerce 'Elive::Entity::Group' => from 'HashRef'
+          => via {Elive::Entity::Group->construct($_,
+						 %Elive::_construct_opts) };
+
+coerce 'Elive::Entity::Group' => from 'Str'
+          => via {
+	      my $group_id = $_;
+	      $group_id =~ s{^ \s* \* \s*}{}x;  # just in case leading '*' leaks through
+
+	      Elive::Entity::Group->construct({groupId => $group_id}, 
+					      %Elive::_construct_opts) };
+
 =head1 NAME
 
 Elive::Entity::Group - Elluminate Group entity instance class
@@ -35,8 +47,11 @@ Elive::Entity::Group - Elluminate Group entity instance class
 These are used to maintain user groups for general use. In particular,
 for group selection of meeting participants.
 
-The C<members> property contains an array of user IDs.
+The C<members> property contains the group members as an array of user IDs.
 
+If the a site is configured for LDAP, groups are mapped to LDAP groups. 
+Group access becomes read-only. The affected methods are: C<insert>, C<update>,
+and C<delete>.
 =cut
 
 =head1 METHODS
